// -*-Mode: C++;-*- 
/*
 * $Id: ThreadView.h,v 2.1 1999/03/09 01:03:59 ral Exp $
 * Include file for the thread-view-object
 */

#ifndef CThreadView_included
#define CThreadView_included

#include "ListViewData.h"
#include "qtimer.h"

class CThreadView : public CListViewData
{
    Q_OBJECT

public:

    CThreadView(QWidget* parent = NULL,const char* name = NULL);

    virtual ~CThreadView();

protected slots:
    void RefreshList();
    void KillThread();

private:
    QTimer*ResetTimer;
    QPushButton*KillButton;

public slots:
    void hide();
    void show();
};
#endif // CThreadView_included
